==> tgcloud-jupyter-0.6.0.tar.gz: tgcloud-jupyter-0.6.0/setup.py <==
"""
jupyterlab_examples_react_widget setup
"""
import json
import os

from jupyter_packaging import (
    create_cmdclass, install_npm, ensure_targets,
    combine_commands, skip_if_exists
)
import setuptools

HERE = os.path.abspath(os.path.dirname(__file__))

# The name of the project
name="tgcloud-jupyter"

# Get our version
with open(os.path.join(HERE, 'package.json')) as f:
    version = json.load(f)['version']

lab_path = os.path.join(HERE)  #, name, "labextension"

# Representative files that should exist after a successful build
jstargets = [
    os.path.join(lab_path, "package.json"),
]

package_data_spec = {
    name: [
        "*"
    ]
}

labext_name = "@jupyterlab/tgcloud"

data_files_spec = [
    ("share/jupyter/labextensions/%s" % labext_name, lab_path, "**"),
    ("share/jupyter/labextensions/%s" % labext_name, HERE, "install.json"),
]

cmdclass = create_cmdclass("jsdeps",
    package_data_spec=package_data_spec,
    data_files_spec=data_files_spec
)

js_command = combine_commands(
    install_npm(HERE, build_cmd="build:prod", npm=["jlpm"]),
    ensure_targets(jstargets),
)

is_repo = os.path.exists(os.path.join(HERE, ".git"))
if is_repo:
    cmdclass["jsdeps"] = js_command
else:
    cmdclass["jsdeps"] = skip_if_exists(jstargets, js_command)


# ###########
# def runPackLabextension():
#     if Path('package.json').is_file():
#         try:
#             run(['jlpm', 'build:labextension'])
#         except CalledProcessError:
#             pass
# pack_labext = command_for_func(runPackLabextension)

# cmdclass = create_cmdclass('pack_labext', data_files_spec=data_files_spec)
# cmdclass['pack_labext'] = pack_labext
# cmdclass.pop('develop')

# #######


with open("README.md", "r") as fh:
    long_description = fh.read()

setup_args = dict(
    name=name,
    version=version,
    url="https://github.com/zrougamed/tgcloud-jupyterLab.git",
    author="Mohamed Zrouga",
    author_email="medzrouga@gmail.com",
    description="TigerGraph Cloud Extension for JupyterLab/SageMaker",
    long_description= long_description,
    long_description_content_type="text/markdown",
    cmdclass= cmdclass,
    packages=setuptools.find_packages(),
  
    zip_safe=False,
    include_package_data=True,
    python_requires=">=3.6",
    license="BSD-3-Clause",
    platforms="Linux, Mac OS X, Windows",
    keywords=["Jupyter", "JupyterLab", "JupyterLab3"],
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Framework :: Jupyter",
    ],
)


if __name__ == "__main__":
    setuptools.setup(**setup_args)

==> tgcloud-jupyter-0.9.0.tar.gz: tgcloud-jupyter-0.9.0/setup.py <==
"""
jupyterlab_examples_react_widget setup
"""
import json
import os

from jupyter_packaging import (
    create_cmdclass, install_npm, ensure_targets,
    combine_commands, skip_if_exists
)
import setuptools

HERE = os.path.abspath(os.path.dirname(__file__))

# The name of the project
name="tgcloud-jupyter"

# Get our version
with open(os.path.join(HERE, 'package.json')) as f:
    version = json.load(f)['version']

lab_path = os.path.join(HERE)  #, name, "labextension"

# Representative files that should exist after a successful build
jstargets = [
    os.path.join(lab_path, "package.json"),
]

package_data_spec = {
    name: [
        "*"
    ]
}

labext_name = "@jupyterlab/tgcloud"

data_files_spec = [
    ("share/jupyter/labextensions/%s" % name, lab_path, "**"),
    ("share/jupyter/labextensions/%s" % name, HERE, "install.json"),
]

cmdclass = create_cmdclass("jsdeps",
    package_data_spec=package_data_spec,
    data_files_spec=data_files_spec
)

js_command = combine_commands(
    install_npm("share/jupyter/labextensions/%s" % name, build_cmd="build", npm=["jlpm"]),
    ensure_targets(jstargets),
)

is_repo = os.path.exists(os.path.join(HERE, ".git"))
if is_repo:
    cmdclass["jsdeps"] = js_command
else:
    cmdclass["jsdeps"] = skip_if_exists(jstargets, js_command)


# ###########
# def runPackLabextension():
#     if Path('package.json').is_file():
#         try:
#             run(['jlpm', 'build:labextension'])
#         except CalledProcessError:
#             pass
# pack_labext = command_for_func(runPackLabextension)

# cmdclass = create_cmdclass('pack_labext', data_files_spec=data_files_spec)
# cmdclass['pack_labext'] = pack_labext
# cmdclass.pop('develop')

# #######


with open("README.md", "r") as fh:
    long_description = fh.read()

setup_args = dict(
    name=name,
    version=version,
    url="https://github.com/zrougamed/tgcloud-jupyterLab.git",
    author="Mohamed Zrouga",
    author_email="medzrouga@gmail.com",
    description="TigerGraph Cloud Extension for JupyterLab/SageMaker",
    long_description= long_description,
    long_description_content_type="text/markdown",
    cmdclass= cmdclass,
    packages=setuptools.find_packages(),
  
    zip_safe=False,
    include_package_data=True,
    python_requires=">=3.6",
    license="BSD-3-Clause",
    platforms="Linux, Mac OS X, Windows",
    keywords=["Jupyter", "JupyterLab", "JupyterLab3"],
    classifiers=[
        "License :: OSI Approved :: BSD License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Framework :: Jupyter",
    ],
)


if __name__ == "__main__":
    setuptools.setup(**setup_args)
